# AutoML

# Running

Run the following commands in project root

1. Run `python3 -m venv .venv`  - This is only done once. Try restaring the editor the VSCODE shows local virtual enviroment.
2. Run `pip install -r requirements.txt` (After activating the virtual enviroment)
3. 
## Structure of Project

- `friday/` - source code area
- `docs/` - any other documentation files
- `tests/` - a directory to hold the tests for the projects  

## Submitting Code

1. Create a new branch with name starting like `bugfix-<issuenum>` or `feature-<featurename>` or `docs-<name>`.
2. Add the code and add also what does it do and how does it do in comments.
3. commit the changes with the summmary of the changes.
4. push to that branch and create a merge request.
